# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from team_member_server_sdk.api.team_member_api import TeamMemberApi  # noqa: E501


class TestTeamMemberApi(unittest.IsolatedAsyncioTestCase):
    """TeamMemberApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = TeamMemberApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_activate_team_member_v1_team_member_activate_post(self) -> None:
        """Test case for activate_team_member_v1_team_member_activate_post

        Activate Team Member  # noqa: E501
        """
        pass

    async def test_disable_team_member_v1_team_member_disable_post(self) -> None:
        """Test case for disable_team_member_v1_team_member_disable_post

        Disable Team Member  # noqa: E501
        """
        pass

    async def test_enable_team_member_v1_team_member_enable_post(self) -> None:
        """Test case for enable_team_member_v1_team_member_enable_post

        Enable Team Member  # noqa: E501
        """
        pass

    async def test_get_team_member_access_v1_team_member_access_get_post(self) -> None:
        """Test case for get_team_member_access_v1_team_member_access_get_post

        Get Team Member access  # noqa: E501
        """
        pass

    async def test_get_team_members_amount_v1_team_member_count_post(self) -> None:
        """Test case for get_team_members_amount_v1_team_member_count_post

        Get Team Members amount  # noqa: E501
        """
        pass

    async def test_get_team_members_v1_team_member_list_post(self) -> None:
        """Test case for get_team_members_v1_team_member_list_post

        Get Team Members  # noqa: E501
        """
        pass

    async def test_invite_team_member_v1_team_member_invite_post(self) -> None:
        """Test case for invite_team_member_v1_team_member_invite_post

        Invite new Team Member  # noqa: E501
        """
        pass

    async def test_remove_team_members_v1_team_member_delete_post(self) -> None:
        """Test case for remove_team_members_v1_team_member_delete_post

        Remove Team Member  # noqa: E501
        """
        pass

    async def test_resend_invitation_email_v1_team_member_email_resend_post(self) -> None:
        """Test case for resend_invitation_email_v1_team_member_email_resend_post

        Resend invitation email  # noqa: E501
        """
        pass

    async def test_update_team_members_v1_team_member_update_post(self) -> None:
        """Test case for update_team_members_v1_team_member_update_post

        Update Team Member  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
