# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, conlist, validator
from team_member_server_sdk.models.team_member_role_response import TeamMemberRoleResponse

class WrappedResponseListTeamMemberRoleResponse(BaseModel):
    """
    WrappedResponseListTeamMemberRoleResponse
    """
    done: Optional[StrictBool] = True
    result: conlist(TeamMemberRoleResponse) = Field(...)
    __properties = ["done", "result"]

    @validator('done')
    def done_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('true',):
            raise ValueError("must be one of enum values ('true')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WrappedResponseListTeamMemberRoleResponse:
        """Create an instance of WrappedResponseListTeamMemberRoleResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in result (list)
        _items = []
        if self.result:
            for _item in self.result:
                if _item:
                    _items.append(_item.to_dict())
            _dict['result'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WrappedResponseListTeamMemberRoleResponse:
        """Create an instance of WrappedResponseListTeamMemberRoleResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WrappedResponseListTeamMemberRoleResponse.parse_obj(obj)

        _obj = WrappedResponseListTeamMemberRoleResponse.parse_obj({
            "done": obj.get("done") if obj.get("done") is not None else True,
            "result": [TeamMemberRoleResponse.from_dict(_item) for _item in obj.get("result")] if obj.get("result") is not None else None
        })
        return _obj


