# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from team_member_server_sdk.models.settings_operation import SettingsOperation  # noqa: E501

class TestSettingsOperation(unittest.TestCase):
    """SettingsOperation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSettingsOperation(self):
        """Test SettingsOperation"""
        # inst = SettingsOperation()

if __name__ == '__main__':
    unittest.main()
